#!/bin/csh

# Author: Jon Meyer, jmeyer@ucsd.edu, 
# based on a script by Jeff Laughlin, jlaughlin@ucsd.edu
# Created: 2006-03-11
#
# Copies ALL EM120 data, but ONLY for the current cruise. 
# Any missing data from a previous cruise must be copied by hand.
#
# rsync is used to only copy NEW data, data that already has been copied
# is not copied again. rsync intelligently looks at file contents and
# can copy and append only the changes to files, so this script may
# be run more frequently than once a day, and will only copy updated
# data.
#
# Note that rsync will not delete anything in the target directory, 
# unless the --delete flag is used, which we don't use, here.
#
# Note that this script uses the $CRUISE variable, 
# which is set elsewhere (/scgscg/files/CRUISE.LEG).
# This file gets source'd in ~/.cshrc, which I call below.
#
# For some reason rsyncing to host em120-103 only works with 
# --blocking-io set, otherwise you get weird errors
# NOTE: using recursive option, preserving times,not using verbose mode 
# to keep cron from emailing unless there is a failure.

# MAIN

# set up some useful variables
set rsyncCmd          = "/usr/local/bin/rsync --blocking-io -e rsh -t -r "
set localEM120RawDir  = /EM120.Data/raw/${CRUISE}
set remoteEM120RawDir = /data1/raw/${CRUISE}
set remoteEM120Host   = em120-103.rrevelle.sio.ucsd.edu

# ensure the local target directory exists
# echo we created it so that cron emails about it
if (! -e ${localEM120RawDir} ) then
	mkdir ${localEM120RawDir}
	echo "created directory, ${localEM120RawDir}";
endif

# open up all directories and files under this directory for 
# user+group read/write permission, only for the upcoming rsync operation
find ${localEM120RawDir} -type d -exec chmod 0775 {} \;
find ${localEM120RawDir} -type f -exec chmod 0664 {} \;

# rsync remote EM120 raw data into a raw directory, here.
# NOTE THE TRAILING SLASH ON THE SOURCE FOLDER -- VERY IMPORTANT
${rsyncCmd} ${remoteEM120Host}:${remoteEM120RawDir}/ ${localEM120RawDir}

# ensure everyone can read, but nobody can overwrite this data
find ${localEM120RawDir} -type d -exec chmod 0555 {} \;
find ${localEM120RawDir} -type f -exec chmod 0444 {} \;
