#!/usr/bin/perl
print STDOUT `echo executing $0 at \`date\``;
#
# This script strips lines from a file that start with the characters 23
# unless the input file starts with values 0-22. This is useful for
# input files that start with times since this script will remove the last
# few minutes of the previous day.
#
# For example, the file:
#   23.95 36.6693 -123.836  99.0 304.9
#   23.9667 36.6694 -123.836  99.0 307.3
#   23.9833 36.6693 -123.836  99.0 305.8
#   0 36.6693 -123.836  99.0 303.7
#   0.0166667 36.6693 -123.836  99.0 303.3
#   0.0333333 36.6693 -123.836  99.0 302.9
# will become:
#   0 36.6693 -123.836  99.0 303.7
#   0.0166667 36.6693 -123.836  99.0 303.3
#   0.0333333 36.6693 -123.836  99.0 302.9
# while the file:
#   0.0333333 36.6693 -123.836  99.0 302.9
#   23.95 36.6693 -123.836  99.0 304.9
#   23.9667 36.6694 -123.836  99.0 307.3
#   23.9833 36.6693 -123.836  99.0 305.8
# will not change.
#
# Author: Steve Foley
# Date created: 23 Jul 2002
#
# data is taken on standard in, output on standard out.

$NEW_DAY = 0;

while (<STDIN>)
{
   # If we saw a new day, just output the rest of the file
   if ($NEW_DAY)
   {
      print $_;
   } 
   else # We need to figure out if we have a new day
   {
      if (/^23.*/)
      {
         next; # still on the old day, keep trying
      }
      else
      {
         $NEW_DAY = 1;
         print $_;
      }
   }
}
